@@ -43,8 +43,8 @@ class Image(Media):
             raise Exception(f"unknown data type {type(data)}")
 
         # caption, boxes 처리
-        self.caption = caption
-        self.boxes = None
+        self.caption :str = caption
+        self.boxes :Dict = None
 
         if boxes:
             if isinstance(boxes, BoundingBoxes):
@@ -70,7 +70,7 @@ class Image(Media):
             "width": self.width,
             "format": self.format,
             "caption": self.caption if self.caption else "",
-            "boxes": self.boxes.to_json() if self.boxes else "",
+            "boxes": self.boxes.to_dict() if self.boxes else "",
 
         })
 
