@@ -153,7 +153,7 @@ def run_optimize(exp_name: str = "", team_name: str = "", func: Callable = None,
         deepdriver.init(exp_name=exp_name)
         get_config(trial, config)
         y = func()
-        deepdriver.log(deepdriver.config.__dict__)
+        deepdriver.log( {"result_score" : y})
         deepdriver.finish()
         return y
 
